@@ -1,5 +1,6 @@
 #define MM_PRIVATE
 #include "mm.h"
+
 /*
  * Insert a chunk to the list of free chunks. Algorithm used is:
  * Insert in sorted manner to the list and merge with previous
@@ -13,8 +14,8 @@ static void mma_insert_chunk(MM *mm, mem_chunk *mcInsert)
     mem_chunk *mcPrevPrev;
     mem_chunk *mcNext;
 
-/*    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
-      return; */
+//    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+//        return;
     mc = &(mm->mp_freechunks);
     mcPrevPrev = mc;
     while (mc->mc_u.mc_next != NULL && (char *)(mc->mc_u.mc_next) < (char *)mcInsert) {
@@ -24,7 +25,7 @@ static void mma_insert_chunk(MM *mm, mem_chunk *mcInsert)
     mcPrev = mc;
     mcNext = mc->mc_u.mc_next;
     if (mcPrev == mcInsert || mcNext == mcInsert) {
-/*        mm_core_unlock((void *)mm); */
+//        mm_core_unlock((void *)mm);
         ERR(MM_ERR_ALLOC, "chunk of memory already in free list");
         return;
     }
@@ -62,7 +63,7 @@ static void mma_insert_chunk(MM *mm, mem_chunk *mcInsert)
         mcPrev->mc_u.mc_next = mcInsert;
         mm->mp_freechunks.mc_usize += 1;
     }
-/*    mm_core_unlock((void *)mm); */
+//    mm_core_unlock((void *)mm);
     return;
 }
 
@@ -85,8 +86,8 @@ static mem_chunk *mma_retrieve_chunk(MM *mm, size_t size)
         return NULL;
     if (mm->mp_freechunks.mc_usize == 0)
         return NULL;
-/*    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
-        return NULL; */
+//    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+//        return NULL;
 
     /* find best-fitting chunk */
     pmcMin = NULL;
@@ -126,7 +127,7 @@ static mem_chunk *mma_retrieve_chunk(MM *mm, size_t size)
         }
     }
 
-/*    mm_core_unlock((void *)mm); */
+//    mm_core_unlock((void *)mm);
     return mcRes;
 }
 
@@ -146,10 +147,10 @@ void *mma_malloc(MM *mm, size_t usize)
         mc->mc_usize = usize;
         return &(mc->mc_u.mc_base.mw_cp);
     }
-/*    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
-        return NULL; */
+//    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+//        return NULL;
     if ((mm->mp_size - mm->mp_offset) < size) {
-/*        mm_core_unlock((void *)mm); */
+//        mm_core_unlock((void *)mm);
         ERR(MM_ERR_ALLOC, "out of memory");
         errno = ENOMEM;
         return NULL;
@@ -159,7 +160,7 @@ void *mma_malloc(MM *mm, size_t usize)
     mc->mc_usize = usize;
     vp = (void *)&(mc->mc_u.mc_base.mw_cp);
     mm->mp_offset += size;
-/*    mm_core_unlock((void *)mm); */
+//    mm_core_unlock((void *)mm);
     return vp;
 }
 
@@ -192,26 +193,20 @@ void *mma_calloc(MM *mm, size_t number, size_t usize)
     return vp;
 }
 
-/*
- * Return whether an existing memory chunk has the same allocation
- *  as a requested new size, and if so return 1 and store the new size
+/* 
+ * Return whether existing memory chunk has same allocation 
+ *  as requested siz,e and if so store new size
  */
-int mma_sizeok (void *ptr, const size_t usize) {
+int mma_sizeok (void *ptr, const size_t usize) 
+{
     mem_chunk *mc;
-
+    
     if (ptr == NULL) return 0;
     mc = (mem_chunk *)((char *)ptr - SIZEOF_mem_chunk);
-
-    if (usize >  mc->mc_size - SIZEOF_mem_chunk
-     || usize <= mc->mc_size - SIZEOF_mem_chunk - sizeof(union mem_chunk_mc_u)) return 0;
-
+    
+    if (usize > mc->mc_size
+     || usize < mc->mc_size - sizeof(union mem_chunk_mc_u)) return 0;
+    
     mc->mc_usize = usize;
-    return 1;
+    return 1;    
 }
-
-/*
- * Return allocation block size and allocation base size
-   inline is removed if necessary by Makefile.PL */
-
-inline int mma_alloc_mask(void) {return sizeof(union mem_chunk_mc_u)-1;}
-inline int mma_alloc_base(void) {return SIZEOF_mem_chunk;}
